@@ -9,11 +9,11 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.ElasticTranscoder 1.17.102\n"
-        "Version:         1.17.102\n"
-        "Builder version: 4.20.0\n"
+        "Type annotations for boto3.ElasticTranscoder 1.17.103\n"
+        "Version:         1.17.103.post1\n"
+        "Builder version: 4.22.1\n"
         "Docs:            https://pypi.org/project/mypy-boto3-elastictranscoder/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
@@ -23,7 +23,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.17.102")
+    print("1.17.103.post1")
 
 
 def main() -> None:
