@@ -15,7 +15,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .paginator import (
     ListJobsByPipelinePaginator,
@@ -27,24 +27,24 @@ from .type_defs import (
     AudioParametersTypeDef,
     CreateJobOutputTypeDef,
     CreateJobPlaylistTypeDef,
-    CreateJobResponseResponseTypeDef,
-    CreatePipelineResponseResponseTypeDef,
-    CreatePresetResponseResponseTypeDef,
+    CreateJobResponseTypeDef,
+    CreatePipelineResponseTypeDef,
+    CreatePresetResponseTypeDef,
     JobInputTypeDef,
-    ListJobsByPipelineResponseResponseTypeDef,
-    ListJobsByStatusResponseResponseTypeDef,
-    ListPipelinesResponseResponseTypeDef,
-    ListPresetsResponseResponseTypeDef,
+    ListJobsByPipelineResponseTypeDef,
+    ListJobsByStatusResponseTypeDef,
+    ListPipelinesResponseTypeDef,
+    ListPresetsResponseTypeDef,
     NotificationsTypeDef,
     PipelineOutputConfigTypeDef,
-    ReadJobResponseResponseTypeDef,
-    ReadPipelineResponseResponseTypeDef,
-    ReadPresetResponseResponseTypeDef,
-    TestRoleResponseResponseTypeDef,
+    ReadJobResponseTypeDef,
+    ReadPipelineResponseTypeDef,
+    ReadPresetResponseTypeDef,
+    TestRoleResponseTypeDef,
     ThumbnailsTypeDef,
-    UpdatePipelineNotificationsResponseResponseTypeDef,
-    UpdatePipelineResponseResponseTypeDef,
-    UpdatePipelineStatusResponseResponseTypeDef,
+    UpdatePipelineNotificationsResponseTypeDef,
+    UpdatePipelineResponseTypeDef,
+    UpdatePipelineStatusResponseTypeDef,
     VideoParametersTypeDef,
 )
 from .waiter import JobCompleteWaiter
@@ -77,20 +77,25 @@ class Exceptions:
     ValidationException: Type[BotocoreClientError]
 
 
-class ElasticTranscoderClient:
+class ElasticTranscoderClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        ElasticTranscoderClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#can_paginate)
         """
 
@@ -98,7 +103,7 @@ class ElasticTranscoderClient:
         """
         The CancelJob operation cancels an unfinished job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Client.cancel_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Client.cancel_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#cancel_job)
         """
 
@@ -113,12 +118,12 @@ class ElasticTranscoderClient:
         OutputKeyPrefix: str = None,
         Playlists: List["CreateJobPlaylistTypeDef"] = None,
         UserMetadata: Dict[str, str] = None
-    ) -> CreateJobResponseResponseTypeDef:
+    ) -> CreateJobResponseTypeDef:
         """
         When you create a job, Elastic Transcoder returns JSON data that includes the
         values that you specified plus information about the job that is created.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#create_job)
         """
 
@@ -133,11 +138,11 @@ class ElasticTranscoderClient:
         Notifications: "NotificationsTypeDef" = None,
         ContentConfig: "PipelineOutputConfigTypeDef" = None,
         ThumbnailConfig: "PipelineOutputConfigTypeDef" = None
-    ) -> CreatePipelineResponseResponseTypeDef:
+    ) -> CreatePipelineResponseTypeDef:
         """
         The CreatePipeline operation creates a pipeline with settings that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#create_pipeline)
         """
 
@@ -150,11 +155,11 @@ class ElasticTranscoderClient:
         Video: "VideoParametersTypeDef" = None,
         Audio: "AudioParametersTypeDef" = None,
         Thumbnails: "ThumbnailsTypeDef" = None
-    ) -> CreatePresetResponseResponseTypeDef:
+    ) -> CreatePresetResponseTypeDef:
         """
         The CreatePreset operation creates a preset with settings that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_preset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_preset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#create_preset)
         """
 
@@ -162,7 +167,7 @@ class ElasticTranscoderClient:
         """
         The DeletePipeline operation removes a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Client.delete_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Client.delete_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#delete_pipeline)
         """
 
@@ -170,7 +175,7 @@ class ElasticTranscoderClient:
         """
         The DeletePreset operation removes a preset that you've added in an AWS region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Client.delete_preset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Client.delete_preset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#delete_preset)
         """
 
@@ -184,84 +189,84 @@ class ElasticTranscoderClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#generate_presigned_url)
         """
 
     def list_jobs_by_pipeline(
         self, *, PipelineId: str, Ascending: str = None, PageToken: str = None
-    ) -> ListJobsByPipelineResponseResponseTypeDef:
+    ) -> ListJobsByPipelineResponseTypeDef:
         """
         The ListJobsByPipeline operation gets a list of the jobs currently in a
         pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_jobs_by_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_jobs_by_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#list_jobs_by_pipeline)
         """
 
     def list_jobs_by_status(
         self, *, Status: str, Ascending: str = None, PageToken: str = None
-    ) -> ListJobsByStatusResponseResponseTypeDef:
+    ) -> ListJobsByStatusResponseTypeDef:
         """
         The ListJobsByStatus operation gets a list of jobs that have a specified status.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_jobs_by_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_jobs_by_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#list_jobs_by_status)
         """
 
     def list_pipelines(
         self, *, Ascending: str = None, PageToken: str = None
-    ) -> ListPipelinesResponseResponseTypeDef:
+    ) -> ListPipelinesResponseTypeDef:
         """
         The ListPipelines operation gets a list of the pipelines associated with the
         current AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_pipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#list_pipelines)
         """
 
     def list_presets(
         self, *, Ascending: str = None, PageToken: str = None
-    ) -> ListPresetsResponseResponseTypeDef:
+    ) -> ListPresetsResponseTypeDef:
         """
         The ListPresets operation gets a list of the default presets included with
         Elastic Transcoder and the presets that you've added in an AWS region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_presets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_presets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#list_presets)
         """
 
-    def read_job(self, *, Id: str) -> ReadJobResponseResponseTypeDef:
+    def read_job(self, *, Id: str) -> ReadJobResponseTypeDef:
         """
         The ReadJob operation returns detailed information about a job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#read_job)
         """
 
-    def read_pipeline(self, *, Id: str) -> ReadPipelineResponseResponseTypeDef:
+    def read_pipeline(self, *, Id: str) -> ReadPipelineResponseTypeDef:
         """
         The ReadPipeline operation gets detailed information about a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#read_pipeline)
         """
 
-    def read_preset(self, *, Id: str) -> ReadPresetResponseResponseTypeDef:
+    def read_preset(self, *, Id: str) -> ReadPresetResponseTypeDef:
         """
         The ReadPreset operation gets detailed information about a preset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_preset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_preset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#read_preset)
         """
 
     def test_role(
         self, *, Role: str, InputBucket: str, OutputBucket: str, Topics: List[str]
-    ) -> TestRoleResponseResponseTypeDef:
+    ) -> TestRoleResponseTypeDef:
         """
         The TestRole operation tests the IAM role used to create the pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Client.test_role)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Client.test_role)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#test_role)
         """
 
@@ -276,33 +281,33 @@ class ElasticTranscoderClient:
         Notifications: "NotificationsTypeDef" = None,
         ContentConfig: "PipelineOutputConfigTypeDef" = None,
         ThumbnailConfig: "PipelineOutputConfigTypeDef" = None
-    ) -> UpdatePipelineResponseResponseTypeDef:
+    ) -> UpdatePipelineResponseTypeDef:
         """
         Use the `UpdatePipeline` operation to update settings for a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#update_pipeline)
         """
 
     def update_pipeline_notifications(
         self, *, Id: str, Notifications: "NotificationsTypeDef"
-    ) -> UpdatePipelineNotificationsResponseResponseTypeDef:
+    ) -> UpdatePipelineNotificationsResponseTypeDef:
         """
         With the UpdatePipelineNotifications operation, you can update Amazon Simple
         Notification Service (Amazon SNS) notifications for a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline_notifications)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline_notifications)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#update_pipeline_notifications)
         """
 
     def update_pipeline_status(
         self, *, Id: str, Status: str
-    ) -> UpdatePipelineStatusResponseResponseTypeDef:
+    ) -> UpdatePipelineStatusResponseTypeDef:
         """
         The UpdatePipelineStatus operation pauses or reactivates a pipeline, so that the
         pipeline stops or restarts the processing of jobs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#update_pipeline_status)
         """
 
@@ -311,7 +316,7 @@ class ElasticTranscoderClient:
         self, operation_name: Literal["list_jobs_by_pipeline"]
     ) -> ListJobsByPipelinePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByPipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByPipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listjobsbypipelinepaginator)
         """
 
@@ -320,26 +325,26 @@ class ElasticTranscoderClient:
         self, operation_name: Literal["list_jobs_by_status"]
     ) -> ListJobsByStatusPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByStatus)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByStatus)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listjobsbystatuspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_pipelines"]) -> ListPipelinesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listpipelinespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_presets"]) -> ListPresetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPresets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPresets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listpresetspaginator)
         """
 
     def get_waiter(self, waiter_name: Literal["job_complete"]) -> JobCompleteWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Waiter.JobComplete)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Waiter.JobComplete)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/waiters.html#jobcompletewaiter)
         """
