@@ -29,10 +29,10 @@ from typing import Iterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .type_defs import (
-    ListJobsByPipelineResponseResponseTypeDef,
-    ListJobsByStatusResponseResponseTypeDef,
-    ListPipelinesResponseResponseTypeDef,
-    ListPresetsResponseResponseTypeDef,
+    ListJobsByPipelineResponseTypeDef,
+    ListJobsByStatusResponseTypeDef,
+    ListPipelinesResponseTypeDef,
+    ListPresetsResponseTypeDef,
     PaginatorConfigTypeDef,
 )
 
@@ -46,7 +46,7 @@ __all__ = (
 
 class ListJobsByPipelinePaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByPipeline)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByPipeline)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listjobsbypipelinepaginator)
     """
 
@@ -56,53 +56,53 @@ class ListJobsByPipelinePaginator(Boto3Paginator):
         PipelineId: str,
         Ascending: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListJobsByPipelineResponseResponseTypeDef]:
+    ) -> Iterator[ListJobsByPipelineResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByPipeline.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByPipeline.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listjobsbypipelinepaginator)
         """
 
 
 class ListJobsByStatusPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByStatus)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByStatus)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listjobsbystatuspaginator)
     """
 
     def paginate(
         self, *, Status: str, Ascending: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListJobsByStatusResponseResponseTypeDef]:
+    ) -> Iterator[ListJobsByStatusResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByStatus.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByStatus.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listjobsbystatuspaginator)
         """
 
 
 class ListPipelinesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPipelines)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPipelines)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listpipelinespaginator)
     """
 
     def paginate(
         self, *, Ascending: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListPipelinesResponseResponseTypeDef]:
+    ) -> Iterator[ListPipelinesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPipelines.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPipelines.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listpipelinespaginator)
         """
 
 
 class ListPresetsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPresets)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPresets)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listpresetspaginator)
     """
 
     def paginate(
         self, *, Ascending: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListPresetsResponseResponseTypeDef]:
+    ) -> Iterator[ListPresetsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPresets.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPresets.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listpresetspaginator)
         """
